==> haskell-cryptohash-cryptoapi-0.1.4-266-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-1RNa2qSgJfYI0ajogJNPPj
key:                  cryptohash-cryptoapi-0.1.4-1RNa2qSgJfYI0ajogJNPPj
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  12bfbf844a0ace057a7788b9273278b9
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-cryptoapi
hs-libraries:         HScryptohash-cryptoapi-0.1.4-1RNa2qSgJfYI0ajogJNPPj
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    crypto-api-0.13.3-H2rQjLwJg166An3m7THxYG
    cryptonite-0.30-1Rfjg2UxJ0tAQrwWuK0NlN
    memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-282-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-465gN4nTXPT6aKY9sejAG8
key:                  cryptohash-cryptoapi-0.1.4-465gN4nTXPT6aKY9sejAG8
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  3f51e62a60e00c93f38c305a12c17f4a
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-cryptoapi
hs-libraries:         HScryptohash-cryptoapi-0.1.4-465gN4nTXPT6aKY9sejAG8
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    crypto-api-0.13.3-EHPdhbKdFzpJPwJ37IaBSu
    cryptonite-0.30-A2WcUXrCplbraDFo3HWcX
    memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
